==> gravitino-0.9.1-src.tar.gz: gravitino-0.9.1-src/core/src/main/java/org/apache/gravitino/metrics/source/RelationDatasourceMetricsSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.gravitino.metrics.source;

import com.codahale.metrics.Gauge;
import org.apache.commons.dbcp2.BasicDataSource;
import org.apache.gravitino.metrics.MetricNames;

public class RelationDatasourceMetricsSource extends MetricsSource {

  public RelationDatasourceMetricsSource(BasicDataSource dataSource) {
    super(MetricsSource.GRAVITINO_SERVER_METRIC_NAME);
    registerGauge(
        MetricNames.ENTITY_STORE_RELATION_DATASOURCE_ACTIVE_CONNECTIONS,
        (Gauge<Integer>) dataSource::getNumActive);
    registerGauge(
        MetricNames.ENTITY_STORE_RELATION_DATASOURCE_IDLE_CONNECTIONS,
        (Gauge<Integer>) dataSource::getNumIdle);
    registerGauge(
        MetricNames.ENTITY_STORE_RELATION_DATASOURCE_MAX_CONNECTIONS,
        (Gauge<Integer>) dataSource::getMaxTotal);
  }
}

==> gravitino-1.0.1-src.tar.gz: gravitino-1.0.1-src/core/src/main/java/org/apache/gravitino/metrics/source/RelationDatasourceMetricsSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.gravitino.metrics.source;

import com.codahale.metrics.Gauge;
import org.apache.commons.dbcp2.BasicDataSource;
import org.apache.gravitino.metrics.MetricNames;

public class RelationDatasourceMetricsSource extends MetricsSource {

  public RelationDatasourceMetricsSource(BasicDataSource dataSource) {
    super(MetricsSource.GRAVITINO_RELATIONAL_STORE_METRIC_NAME);
    registerGauge(
        MetricNames.DATASOURCE_ACTIVE_CONNECTIONS, (Gauge<Integer>) dataSource::getNumActive);
    registerGauge(MetricNames.DATASOURCE_IDLE_CONNECTIONS, (Gauge<Integer>) dataSource::getNumIdle);
    registerGauge(MetricNames.DATASOURCE_MAX_CONNECTIONS, (Gauge<Integer>) dataSource::getMaxTotal);
  }
}
